@@ -11,7 +11,7 @@ import backoff as backoff_module
 from singer.catalog import Catalog
 
 DATETIME_PARSE = "%Y-%m-%dT%H:%M:%SZ"
-DATETIME_FMT = "%Y-%m-%dT%H:%M:%S.%fZ"
+DATETIME_FMT = "%04Y-%m-%dT%H:%M:%S.%fZ"
 
 def now():
     return datetime.datetime.utcnow().replace(tzinfo=pytz.UTC)
@@ -174,11 +174,11 @@ def exception_is_4xx(exception):
 def handle_top_exception(logger):
     """A decorator that will catch exceptions and log the exception's message
     as a CRITICAL log."""
-    def decorator(fn):
-        @functools.wraps(fn)
+    def decorator(fnc):
+        @functools.wraps(fnc)
         def wrapped(*args, **kwargs):
             try:
-                return fn(*args, **kwargs)
+                return fnc(*args, **kwargs)
             except Exception as exc:
                 logger.critical(exc)
                 raise
